import numpy

def name(first, last):
    """returns full data of parameters"""

    full = first + " " + last
    full = full.lower().title().strip()
    return "Witaj: " + full

def get_numpu_arr(lst):
    pass
